@@ -25,38 +25,34 @@ class ListDataServiceGroupsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'ListDataServiceGroups')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_PageSize(self):
+	def get_PageSize(self): # Integer
 		return self.get_body_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
+	def set_PageSize(self, PageSize):  # Integer
 		self.add_body_params('PageSize', PageSize)
-
-	def get_TenantId(self):
+	def get_TenantId(self): # Long
 		return self.get_body_params().get('TenantId')
 
-	def set_TenantId(self,TenantId):
+	def set_TenantId(self, TenantId):  # Long
 		self.add_body_params('TenantId', TenantId)
-
-	def get_ProjectId(self):
+	def get_ProjectId(self): # Long
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # Long
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_GroupNameKeyword(self):
+	def get_GroupNameKeyword(self): # String
 		return self.get_body_params().get('GroupNameKeyword')
 
-	def set_GroupNameKeyword(self,GroupNameKeyword):
+	def set_GroupNameKeyword(self, GroupNameKeyword):  # String
 		self.add_body_params('GroupNameKeyword', GroupNameKeyword)
-
-	def get_PageNumber(self):
+	def get_PageNumber(self): # Integer
 		return self.get_body_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_body_params('PageNumber', PageNumber)
\ No newline at end of file
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_body_params('PageNumber', PageNumber)
